@@ -9,11 +9,8 @@
 
 // Qt
 #include <QDateTime>
-#include <QObject>
 #include <QSqlError>
-#include <QSqlQuery>
 #include <QString>
-#include <QStringList>
 
 // Utils
 #include <utils/d_ptr.h>
@@ -21,9 +18,6 @@
 // Local
 #include <common/database/Database.h>
 
-class QDateTime;
-class QSqlError;
-
 namespace Common
 {
 class Database;
